==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/AddWatermark.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.enums.PageOrientation;

@JsonPropertyOrder({
    "@odata.type", 
    "orientation"})
@JsonInclude(Include.NON_NULL)
public class AddWatermark extends MarkContent implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("orientation")
    protected PageOrientation orientation;

    protected AddWatermark() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.addWatermark";
    }

    @Property(name="orientation")
    @JsonIgnore
    public Optional<PageOrientation> getOrientation() {
        return Optional.ofNullable(orientation);
    }

    public AddWatermark withOrientation(PageOrientation orientation) {
        AddWatermark _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.addWatermark");
        _x.orientation = orientation;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAddWatermark() {
        return new Builder();
    }

    public static final class Builder {
        private String name;
        private Long fontSize;
        private String text;
        private String fontColor;
        private PageOrientation orientation;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        public Builder fontSize(Long fontSize) {
            this.fontSize = fontSize;
            this.changedFields = changedFields.add("fontSize");
            return this;
        }

        public Builder text(String text) {
            this.text = text;
            this.changedFields = changedFields.add("text");
            return this;
        }

        public Builder fontColor(String fontColor) {
            this.fontColor = fontColor;
            this.changedFields = changedFields.add("fontColor");
            return this;
        }

        public Builder orientation(PageOrientation orientation) {
            this.orientation = orientation;
            this.changedFields = changedFields.add("orientation");
            return this;
        }

        public AddWatermark build() {
            AddWatermark _x = new AddWatermark();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.addWatermark";
            _x.name = name;
            _x.fontSize = fontSize;
            _x.text = text;
            _x.fontColor = fontColor;
            _x.orientation = orientation;
            return _x;
        }
    }

    private AddWatermark _copy() {
        AddWatermark _x = new AddWatermark();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.name = name;
        _x.fontSize = fontSize;
        _x.text = text;
        _x.fontColor = fontColor;
        _x.orientation = orientation;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AddWatermark[");
        b.append("name=");
        b.append(this.name);
        b.append(", ");
        b.append("fontSize=");
        b.append(this.fontSize);
        b.append(", ");
        b.append("text=");
        b.append(this.text);
        b.append(", ");
        b.append("fontColor=");
        b.append(this.fontColor);
        b.append(", ");
        b.append("orientation=");
        b.append(this.orientation);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/AddWatermark.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.enums.PageOrientation;

@JsonPropertyOrder({
    "@odata.type", 
    "orientation"})
@JsonInclude(Include.NON_NULL)
public class AddWatermark extends MarkContent implements ODataType {

    @JsonProperty("orientation")
    protected PageOrientation orientation;

    protected AddWatermark() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.addWatermark";
    }

    @Property(name="orientation")
    @JsonIgnore
    public Optional<PageOrientation> getOrientation() {
        return Optional.ofNullable(orientation);
    }

    public AddWatermark withOrientation(PageOrientation orientation) {
        AddWatermark _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.addWatermark");
        _x.orientation = orientation;
        return _x;
    }

    public AddWatermark withUnmappedField(String name, Object value) {
        AddWatermark _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAddWatermark() {
        return new Builder();
    }

    public static final class Builder {
        private String name;
        private String fontColor;
        private Long fontSize;
        private String text;
        private PageOrientation orientation;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        public Builder fontColor(String fontColor) {
            this.fontColor = fontColor;
            this.changedFields = changedFields.add("fontColor");
            return this;
        }

        public Builder fontSize(Long fontSize) {
            this.fontSize = fontSize;
            this.changedFields = changedFields.add("fontSize");
            return this;
        }

        public Builder text(String text) {
            this.text = text;
            this.changedFields = changedFields.add("text");
            return this;
        }

        public Builder orientation(PageOrientation orientation) {
            this.orientation = orientation;
            this.changedFields = changedFields.add("orientation");
            return this;
        }

        public AddWatermark build() {
            AddWatermark _x = new AddWatermark();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.addWatermark";
            _x.name = name;
            _x.fontColor = fontColor;
            _x.fontSize = fontSize;
            _x.text = text;
            _x.orientation = orientation;
            return _x;
        }
    }

    private AddWatermark _copy() {
        AddWatermark _x = new AddWatermark();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.name = name;
        _x.fontColor = fontColor;
        _x.fontSize = fontSize;
        _x.text = text;
        _x.orientation = orientation;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AddWatermark[");
        b.append("name=");
        b.append(this.name);
        b.append(", ");
        b.append("fontColor=");
        b.append(this.fontColor);
        b.append(", ");
        b.append("fontSize=");
        b.append(this.fontSize);
        b.append(", ");
        b.append("text=");
        b.append(this.text);
        b.append(", ");
        b.append("orientation=");
        b.append(this.orientation);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
